from setuptools import find_packages, setup
setup(
    name='Stefan_packet',
    version='0.0.1',
    author='Stefan Balan',
    author_email='iibalan92@gmail.com',
    packages=find_packages(),
    include_package_data=False,
    description='A nice library'
)
